============
Installation
============

At the command line::

    pip install pitchly

``pitchly`` works with data loaded using ``kloppy`` and ``codeball`` libraries. It is a prerequisite to get started with ``pitchly``.

You could combine it all with::

    pip install pitchly kloppy codeball
